==> PPDF_1_1.zip: PubMedPDF/upload.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	include "include/conn.php";
	include "include/pubmed.php";
	include "include/db.php";

	$pubmed_xml = "pubmed_xml/";
	if(!is_dir($pubmed_xml))	$rc = mkdir($pubmed_xml, 0777);
	$search_xml = "search_xml/";
	if(!is_dir($search_xml))	$rc = mkdir($search_xml, 0777);
	
	## PDF upload
	if(@$_POST["upload"]){

		# folder for uploaded file
		$up_pass = $xoopsModuleConfig['updir'];
		if(substr($up_pass,-1) != "/") $up_pass.="/";
		if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];

			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				$PMID = substr($file_name,0,-4);
				copy($_FILES['userfile']['tmp_name'], $up_pass.$PMID.".pdf");
				echo "File upload has done.<br><br>[PMID] ".$PMID."<br><br>";

			}else{
				echo "error: This isn't PDF file.<br>";
			}
		}else{
			echo "error: File upload failed.<br>";
		}
	}

	## PMID registration
	if(@$_POST["regist_id"]){
		$PMID = @$_POST["pmid"];
	}

	## Check registration
	$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$PMID."'";
	$res = mysql_query($sql, $conn);
	if(mysql_num_rows($res) != 0){
		echo "This PMID is already registered.<br>";
	
	}else{
		
		## Proxy
		if($xoopsModuleConfig['proxy']){
			include (XOOPS_ROOT_PATH."/class/snoopy.php");
			$proxy = new Snoopy;
			$proxy->read_timeout = 0;
			$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
			$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
		}else{
			$proxy = 0;
		}
		
		## PubMed Search & Fetch

		if(file_exists("$search_xml$PMID.xml")){
			$pm_data = PubMedByFile( $PMID, $search_xml, 0 );
//	     	echo $pm_data[t]."<br>";

			($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
			DB($pm_data, $user);
			echo "<b>[PMID]</b><br>".$pm_data[id]."<br><br>";
			echo "<b>[Journal]</b><br>".$pm_data[j]." v".$pm_data[v]." pp".$pm_data[p]."<br><br>";
			echo "<b>[Year]</b><br>".$pm_data[y]."<br><br>";
			echo "<b>[Title]</b><br>".$pm_data[t]."<br><br>";
			echo "<b>[Authors]</b><br>".$pm_data[a]."<br><br>";
			echo "<b>[Abstract]</b><br>".$pm_data[ab]."<br><br>";

			rename( "$search_xml$PMID.xml", "$pubmed_xml$PMID.xml" );
		} else {
			if(!$pm_data = PubMed($PMID,$proxy,$pubmed_xml)){
				echo "No items found.<br>";
				if(unlink($up_pass.$PMID.".pdf")) echo "Uploaded File deleted.<br>";
			}else{
				($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
				DB($pm_data, $user);
				echo "<b>[PMID]</b><br>".$pm_data[id]."<br><br>";
				echo "<b>[Journal]</b><br>".$pm_data[j]." v".$pm_data[v]." pp".$pm_data[p]."<br><br>";
				echo "<b>[Year]</b><br>".$pm_data[y]."<br><br>";
				echo "<b>[Title]</b><br>".$pm_data[t]."<br><br>";
				echo "<b>[Authors]</b><br>".$pm_data[a]."<br><br>";
				echo "<b>[Abstract]</b><br>".$pm_data[ab]."<br><br>";
			}
		}
	}
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3_1.zip: PubMedPDF/upload.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	include "include/conn.php";
	include "include/pubmed.php";
	include "include/db.php";
	include "include/news.php";

	$pubmed_xml = "pubmed_xml/";
	if(!is_dir($pubmed_xml))	$rc = mkdir($pubmed_xml, 0777);
	$search_xml = "search_xml/";
	if(!is_dir($search_xml))	$rc = mkdir($search_xml, 0777);
	
	## PDF upload
	if(@$_POST["upload"]){

		# folder for uploaded file
		$up_pass = $xoopsModuleConfig['updir'];
		if(substr($up_pass,-1) != "/") $up_pass.="/";
		if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];

			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				$PMID = substr($file_name,0,-4);
				copy($_FILES['userfile']['tmp_name'], $up_pass.$PMID.".pdf");
				echo "File upload has done.<br><br>[PMID] ".$PMID."<br><br>";

			}else{
				echo "error: This isn't PDF file.<br>";
			}
		}else{
			echo "error: File upload failed.<br>";
		}
	}

	## PMID registration
	if(@$_POST["regist_id"]){
		$PMID = @$_POST["pmid"];
	}

	## Check registration
	$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$PMID."'";
	$res = mysql_query($sql, $conn);
	if(mysql_num_rows($res) != 0){
		echo "This PMID is already registered.<br>";
	
	}else{
		
		## Proxy
		include (XOOPS_ROOT_PATH."/class/snoopy.php");
		if($xoopsModuleConfig['proxy']){
			$proxy = new Snoopy;
			$proxy->read_timeout = 0;
			$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
			$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
		}else{
			$proxy = 0;
			$snoopy = new Snoopy;
		}
		
		## PubMed Search & Fetch

		if(file_exists("$search_xml$PMID.xml")){
			$pm_data = PubMedByFile( $PMID, $search_xml, 0 );
//	     	echo $pm_data[t]."<br>";

			($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
			DB($pm_data, $user);
			if($xoopsModuleConfig['news']){
				NEWS_REGISTER("Reg.w.PMID", $pm_data[t], $pm_data[ab], $user);
			}
			echo "<b>[PMID]</b><br>".$pm_data[id]."<br><br>";
			echo "<b>[Journal]</b><br>".$pm_data[j]." v".$pm_data[v]." pp".$pm_data[p]."<br><br>";
			echo "<b>[Year]</b><br>".$pm_data[y]."<br><br>";
			echo "<b>[Title]</b><br>".$pm_data[t]."<br><br>";
			echo "<b>[Authors]</b><br>".$pm_data[a]."<br><br>";
			echo "<b>[Abstract]</b><br>".$pm_data[ab]."<br><br>";

			rename( "$search_xml$PMID.xml", "$pubmed_xml$PMID.xml" );
		} else {
			if(!$pm_data = PubMed($PMID,$proxy,$snoopy,$pubmed_xml)){
				echo "No items found.<br>";
				if(unlink($up_pass.$PMID.".pdf")) echo "Uploaded File deleted.<br>";
			}else{
				($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
				DB($pm_data, $user);
				if($xoopsModuleConfig['news']){
					NEWS_REGISTER("Reg.w.PMID", $pm_data[t], $pm_data[ab], $user);
				}
				echo "<b>[PMID]</b><br>".$pm_data[id]."<br><br>";
				echo "<b>[Journal]</b><br>".$pm_data[j]." v".$pm_data[v]." pp".$pm_data[p]."<br><br>";
				echo "<b>[Year]</b><br>".$pm_data[y]."<br><br>";
				echo "<b>[Title]</b><br>".$pm_data[t]."<br><br>";
				echo "<b>[Authors]</b><br>".$pm_data[a]."<br><br>";
				echo "<b>[Abstract]</b><br>".$pm_data[ab]."<br><br>";
			}
		}
	}
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>
